@@ -10,6 +10,7 @@
 // Older versions of GNU stdint.h require this definition to be able to see INT32_MAX
 #define __STDC_LIMIT_MACROS
 #include <cstdint>
+#include <cassert>
 #include <cstring>
 #include <cstdio>
 #include <ctime>
@@ -22,6 +23,8 @@
 #include <algorithm>
 #include <memory>
 #include <chrono>
+#include <atomic>
+#include <mutex>
 
 #include <fcntl.h>
 
@@ -41,7 +44,6 @@
 #include "StyleWriter.h"
 #include "Extender.h"
 #include "SciTE.h"
-#include "Mutex.h"
 #include "JobQueue.h"
 #include "Cookie.h"
 #include "Worker.h"
@@ -158,11 +160,12 @@ std::string SciTEBase::DiscoverLanguage() {
 	const SA::Position length = std::min<SA::Position>(LengthDocument(), 64 * 1024);
 	std::string buf = wEditor.StringOfRange(SA::Range(0, length));
 	std::string languageOverride = "";
-	std::string l1 = ExtractLine(buf.c_str(), length);
-	if (StartsWith(l1, "<?xml")) {
+	std::string_view line = ExtractLine(buf);
+	if (StartsWith(line, "<?xml")) {
 		languageOverride = "xml";
-	} else if (StartsWith(l1, "#!")) {
-		l1 = l1.substr(2);
+	} else if (StartsWith(line, "#!")) {
+		line.remove_prefix(2);
+		std::string l1(line);
 		std::replace(l1.begin(), l1.end(), '\\', ' ');
 		std::replace(l1.begin(), l1.end(), '/', ' ');
 		std::replace(l1.begin(), l1.end(), '\t', ' ');
@@ -292,7 +295,7 @@ void SciTEBase::OpenCurrentFile(long long fileSize, bool suppressMessage, bool a
 				docOptions = static_cast<SA::DocumentOption>(
 						     static_cast<int>(docOptions) | static_cast<int>(SA::DocumentOption::StylesNone));
 
-			pdocLoad = reinterpret_cast<ILoader *>(
+			pdocLoad = static_cast<ILoader *>(
 					   wEditor.CreateLoader(static_cast<SA::Position>(fileSize) + 1000,
 								docOptions));
 		} catch (...) {
@@ -308,7 +311,7 @@ void SciTEBase::OpenCurrentFile(long long fileSize, bool suppressMessage, bool a
 		Utf8_16_Read convert;
 		std::vector<char> data(blockSize);
 		size_t lenFile = fread(&data[0], 1, data.size(), fp);
-		const UniMode umCodingCookie = CodingCookieValue(&data[0], lenFile);
+		const UniMode umCodingCookie = CodingCookieValue(std::string_view(data.data(), lenFile));
 		while (lenFile > 0) {
 			lenFile = convert.convert(&data[0], lenFile);
 			const char *dataBlock = convert.getNewBuf();
@@ -1096,7 +1099,7 @@ bool SciTEBase::SaveBuffer(const FilePath &saveName, SaveFlags sf) {
 			const size_t lengthDoc = LengthDocument();
 			if (!(sf & sfSynchronous)) {
 				wEditor.SetReadOnly(true);
-				const char *documentBytes = reinterpret_cast<const char *>(wEditor.CharacterPointer());
+				const char *documentBytes = static_cast<const char *>(wEditor.CharacterPointer());
 				CurrentBuffer()->pFileWorker = new FileStorer(this, documentBytes, saveName, lengthDoc, fp, CurrentBuffer()->unicodeMode, (sf & sfProgressVisible));
 				CurrentBuffer()->pFileWorker->sleepTime = props.GetInt("asynchronous.sleep");
 				if (PerformOnNewThread(CurrentBuffer()->pFileWorker)) {
@@ -1290,7 +1293,7 @@ void SciTEBase::OpenFromStdin(bool UseOutputPane) {
 		wEditor.ClearAll();
 	}
 	size_t lenFile = fread(&data[0], 1, data.size(), stdin);
-	const UniMode umCodingCookie = CodingCookieValue(&data[0], lenFile);
+	const UniMode umCodingCookie = CodingCookieValue(std::string_view(data.data(), lenFile));
 	while (lenFile > 0) {
 		lenFile = convert.convert(&data[0], lenFile);
 		if (UseOutputPane) {
@@ -1341,7 +1344,7 @@ void SciTEBase::OpenFromStdin(bool UseOutputPane) {
 }
 
 void SciTEBase::OpenFilesFromStdin() {
-	char data[8 * 1024];
+	char data[8 * 1024] {};
 
 	/* if stdin is blocked, do not execute this method */
 	if (IsStdinBlocked())
@@ -1459,12 +1462,12 @@ public:
 	const char *Original() const noexcept {
 		return lineToShow.c_str();
 	}
-	bool BufferContainsNull() {
+	bool BufferContainsNull() noexcept {
 		return bf->BufferContainsNull();
 	}
 };
 
-static bool IsWordCharacter(int ch) noexcept {
+constexpr bool IsWordCharacter(int ch) noexcept {
 	return (ch >= 'A' && ch <= 'Z') || (ch >= 'a' && ch <= 'z')  || (ch >= '0' && ch <= '9')  || (ch == '_');
 }
 
@@ -1478,7 +1481,7 @@ bool SciTEBase::GrepIntoDirectory(const FilePath &directory) {
 }
 
 void SciTEBase::GrepRecursive(GrepFlags gf, const FilePath &baseDir, const char *searchString, const GUI::gui_char *fileTypes) {
-	const int checkAfterLines = 10'000;
+	constexpr int checkAfterLines = 10'000;
 	FilePathSet directories;
 	FilePathSet files;
 	baseDir.List(directories, files);
