@@ -21,6 +21,8 @@
 #include <algorithm>
 #include <memory>
 #include <chrono>
+#include <atomic>
+#include <mutex>
 
 #include <fcntl.h>
 
@@ -55,7 +57,6 @@ const GUI::gui_char menuAccessIndicator[] = GUI_TEXT("&");
 #include "StyleWriter.h"
 #include "Extender.h"
 #include "SciTE.h"
-#include "Mutex.h"
 #include "JobQueue.h"
 #include "Cookie.h"
 #include "Worker.h"
@@ -140,6 +141,11 @@ void SciTEBase::ReadEnvironment() {
 Read global and user properties files.
 */
 void SciTEBase::ReadGlobalPropFile() {
+	// Appearance and Contrast may be read in embedded or global properties
+	// so set them in deepest property set propsPlatform.
+	propsPlatform.Set("Appearance", StdStringFromInteger(appearance.dark));
+	propsPlatform.Set("Contrast", StdStringFromInteger(appearance.highContrast));
+
 	std::string excludes;
 	std::string includes;
 
@@ -490,6 +496,7 @@ static const char *propertiesToForward[] = {
 	"fold.verilog.flags",
 	"fold.xml.at.tag.open",
 	"html.tags.case.sensitive",
+	"lexer.as.comment.character",
 	"lexer.asm.comment.delimiter",
 	"lexer.baan.styling.within.preprocessor",
 	"lexer.caml.magic",
@@ -660,14 +667,7 @@ void SciTEBase::ReadProperties() {
 		extender->Clear();
 
 	const std::string lexillaPath = props.GetString("lexilla.path");
-	if (lexillaPath.length()) {
-		std::vector<std::string> paths = StringSplit(lexillaPath, ';');
-		FilePathSet fps;
-		for (std::string path : paths) {
-			fps.push_back(FilePath(GUI::StringFromUTF8(path)));
-		}
-		LexillaLoad(fps);
-	}
+	LexillaLoad(lexillaPath.empty() ? "." : lexillaPath);
 
 	const std::string fileNameForExtension = ExtensionFileName();
 
@@ -931,7 +931,7 @@ void SciTEBase::ReadProperties() {
 		else	// Have to show selection somehow
 			CallChildren(SA::Message::SetSelBack, 1, ColourRGB(0xC0, 0xC0, 0xC0));
 	}
-	const int NoAlpha = static_cast<int>(SA::Alpha::NoAlpha);
+	constexpr int NoAlpha = static_cast<int>(SA::Alpha::NoAlpha);
 	const int selectionAlpha = props.GetInt("selection.alpha", NoAlpha);
 	CallChildren(SA::Message::SetSelAlpha, selectionAlpha);
 
@@ -1232,7 +1232,7 @@ void SciTEBase::ReadProperties() {
 	wEditor.SetMarginMaskN(2, SA::MaskFolders);
 	wEditor.SetMarginSensitiveN(2, true);
 
-	// Define foreground (outline) and background (fill) color of folds
+	// Define foreground (outline) and background (fill) colour of folds
 	const int foldSymbols = props.GetInt("fold.symbols");
 	std::string foldFore = props.GetExpandedString("fold.fore");
 	if (foldFore.length() == 0) {
