@@ -202,11 +202,11 @@ bool Selection::IsRectangular() const noexcept {
 	return (selType == selRectangle) || (selType == selThin);
 }
 
-Sci::Position Selection::MainCaret() const {
+Sci::Position Selection::MainCaret() const noexcept {
 	return ranges[mainRange].caret.Position();
 }
 
-Sci::Position Selection::MainAnchor() const {
+Sci::Position Selection::MainAnchor() const noexcept {
 	return ranges[mainRange].anchor.Position();
 }
 
@@ -214,7 +214,7 @@ SelectionRange &Selection::Rectangular() noexcept {
 	return rangeRectangular;
 }
 
-SelectionSegment Selection::Limits() const {
+SelectionSegment Selection::Limits() const noexcept {
 	if (ranges.empty()) {
 		return SelectionSegment();
 	} else {
@@ -248,23 +248,23 @@ void Selection::SetMain(size_t r) noexcept {
 	mainRange = r;
 }
 
-SelectionRange &Selection::Range(size_t r) {
+SelectionRange &Selection::Range(size_t r) noexcept {
 	return ranges[r];
 }
 
-const SelectionRange &Selection::Range(size_t r) const {
+const SelectionRange &Selection::Range(size_t r) const noexcept {
 	return ranges[r];
 }
 
-SelectionRange &Selection::RangeMain() {
+SelectionRange &Selection::RangeMain() noexcept {
 	return ranges[mainRange];
 }
 
-const SelectionRange &Selection::RangeMain() const {
+const SelectionRange &Selection::RangeMain() const noexcept {
 	return ranges[mainRange];
 }
 
-SelectionPosition Selection::Start() const {
+SelectionPosition Selection::Start() const noexcept {
 	if (IsRectangular()) {
 		return rangeRectangular.Start();
 	} else {
@@ -316,7 +316,7 @@ void Selection::MovePositions(bool insertion, Sci::Position startChange, Sci::Po
 	}
 }
 
-void Selection::TrimSelection(SelectionRange range) {
+void Selection::TrimSelection(SelectionRange range) noexcept {
 	for (size_t i=0; i<ranges.size();) {
 		if ((i != mainRange) && (ranges[i].Trim(range))) {
 			// Trimmed to empty so remove
@@ -332,7 +332,7 @@ void Selection::TrimSelection(SelectionRange range) {
 	}
 }
 
-void Selection::TrimOtherSelections(size_t r, SelectionRange range) {
+void Selection::TrimOtherSelections(size_t r, SelectionRange range) noexcept {
 	for (size_t i = 0; i<ranges.size(); ++i) {
 		if (i != r) {
 			ranges[i].Trim(range);
@@ -391,7 +391,7 @@ void Selection::CommitTentative() noexcept {
 	tentativeMain = false;
 }
 
-int Selection::CharacterInSelection(Sci::Position posCharacter) const {
+int Selection::CharacterInSelection(Sci::Position posCharacter) const noexcept {
 	for (size_t i=0; i<ranges.size(); i++) {
 		if (ranges[i].ContainsCharacter(posCharacter))
 			return i == mainRange ? 1 : 2;
@@ -399,7 +399,7 @@ int Selection::CharacterInSelection(Sci::Position posCharacter) const {
 	return 0;
 }
 
-int Selection::InSelectionForEOL(Sci::Position pos) const {
+int Selection::InSelectionForEOL(Sci::Position pos) const noexcept {
 	for (size_t i=0; i<ranges.size(); i++) {
 		if (!ranges[i].Empty() && (pos > ranges[i].Start().Position()) && (pos <= ranges[i].End().Position()))
 			return i == mainRange ? 1 : 2;
