@@ -5,6 +5,9 @@
 // Copyright 2010 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
+#ifndef STRINGHELPERS_H
+#define STRINGHELPERS_H
+
 bool StartsWith(std::wstring_view s, std::wstring_view start);
 bool StartsWith(std::string_view s, std::string_view start);
 bool EndsWith(std::wstring_view s, std::wstring_view end);
@@ -25,6 +28,10 @@ std::string StdStringFromInteger(int i);
 std::string StdStringFromSizeT(size_t i);
 std::string StdStringFromDouble(double d, int precision);
 
+int IntegerFromString(const std::string &val, int defaultValue);
+intptr_t IntPtrFromString(const std::string &val, intptr_t defaultValue);
+long long LongLongFromString(const std::string &val, long long defaultValue);
+
 // Basic case lowering that converts A-Z to a-z.
 // Does not handle non-ASCII characters.
 void LowerCaseAZ(std::string &s);
@@ -33,7 +40,15 @@ constexpr char MakeUpperCase(char ch) noexcept {
 	if (ch < 'a' || ch > 'z')
 		return ch;
 	else
-		return static_cast<char>(ch - 'a' + 'A');
+		return ch - 'a' + 'A';
+}
+
+constexpr char MakeLowerCase(char c) noexcept {
+	if (c >= 'A' && c <= 'Z') {
+		return c - 'A' + 'a';
+	} else {
+		return c;
+	}
 }
 
 constexpr bool IsASCII(int ch) noexcept {
@@ -96,6 +111,7 @@ void StringCopy(T(&dest)[count], const T *source) noexcept {
 
 int CompareNoCase(const char *a, const char *b) noexcept;
 bool EqualCaseInsensitive(const char *a, const char *b) noexcept;
+bool EqualCaseInsensitive(std::string_view a, std::string_view b) noexcept;
 bool isprefix(const char *target, const char *prefix) noexcept;
 
 constexpr const char *UTF8BOM = "\xef\xbb\xbf";
@@ -179,3 +195,5 @@ public:
 };
 
 typedef EntryMemory < 10 > ComboMemory;
+
+#endif
