@@ -10,19 +10,23 @@
 
 namespace Scintilla {
 
-const int UTF8MaxBytes = 4;
+constexpr int UTF8MaxBytes = 4;
 
-const int unicodeReplacementChar = 0xFFFD;
+constexpr int unicodeReplacementChar = 0xFFFD;
 
-size_t UTF8Length(std::wstring_view wsv);
+size_t UTF8Length(std::wstring_view wsv) noexcept;
 size_t UTF8PositionFromUTF16Position(std::string_view u8Text, size_t positionUTF16) noexcept;
-void UTF8FromUTF16(std::wstring_view wsv, char *putf, size_t len);
-void UTF8FromUTF32Character(int uch, char *putf);
-size_t UTF16Length(std::string_view sv);
-size_t UTF16FromUTF8(std::string_view sv, wchar_t *tbuf, size_t tlen);
-size_t UTF32FromUTF8(std::string_view sv, unsigned int *tbuf, size_t tlen);
+void UTF8FromUTF16(std::wstring_view wsv, char *putf, size_t len) noexcept;
+void UTF8FromUTF32Character(int uch, char *putf) noexcept;
+size_t UTF16Length(std::string_view svu8) noexcept;
+size_t UTF16FromUTF8(std::string_view svu8, wchar_t *tbuf, size_t tlen);
+size_t UTF32Length(std::string_view svu8) noexcept;
+size_t UTF32FromUTF8(std::string_view svu8, unsigned int *tbuf, size_t tlen);
+// WStringFromUTF8 does the right thing when wchar_t is 2 or 4 bytes so
+// works on both Windows and Unix.
+std::wstring WStringFromUTF8(std::string_view svu8);
 unsigned int UTF16FromUTF32Character(unsigned int val, wchar_t *tbuf) noexcept;
-bool UTF8IsValid(std::string_view sv) noexcept;
+bool UTF8IsValid(std::string_view svu8) noexcept;
 std::string FixInvalidUTF8(const std::string &text);
 
 extern const unsigned char UTF8BytesOfLead[256];
@@ -60,17 +64,24 @@ int UTF8DrawBytes(const unsigned char *us, int len) noexcept;
 
 // Line separator is U+2028 \xe2\x80\xa8
 // Paragraph separator is U+2029 \xe2\x80\xa9
-const int UTF8SeparatorLength = 3;
+constexpr int UTF8SeparatorLength = 3;
 inline bool UTF8IsSeparator(const unsigned char *us) noexcept {
 	return (us[0] == 0xe2) && (us[1] == 0x80) && ((us[2] == 0xa8) || (us[2] == 0xa9));
 }
 
 // NEL is U+0085 \xc2\x85
-const int UTF8NELLength = 2;
+constexpr int UTF8NELLength = 2;
 inline bool UTF8IsNEL(const unsigned char *us) noexcept {
 	return (us[0] == 0xc2) && (us[1] == 0x85);
 }
 
+// Is the sequence of 3 char a UTF-8 line end? Only the last two char are tested for a NEL. 
+constexpr bool UTF8IsMultibyteLineEnd(unsigned char ch0, unsigned char ch1, unsigned char ch2) noexcept {
+	return
+		((ch0 == 0xe2) && (ch1 == 0x80) && ((ch2 == 0xa8) || (ch2 == 0xa9))) ||
+		((ch1 == 0xc2) && (ch2 == 0x85));
+}
+
 enum { SURROGATE_LEAD_FIRST = 0xD800 };
 enum { SURROGATE_LEAD_LAST = 0xDBFF };
 enum { SURROGATE_TRAIL_FIRST = 0xDC00 };
